summaryrefslogtreecommitdiffstats
path: root/Common/interface
diff options
context:
space:
mode:
authorazhirnov <zh1dron@gmail.com>2020-11-16 17:30:23 +0000
committerazhirnov <zh1dron@gmail.com>2020-11-16 17:53:02 +0000
commit43c3821993cb3d6ec3025fa7156da8544d2a1dac (patch)
treefa5b7cc5774c7f72a307f2b0cd250e64a7abecf0 /Common/interface
parentbug fix for ray tracing, fixed KHR via NV emulation. (diff)
downloadDiligentCore-43c3821993cb3d6ec3025fa7156da8544d2a1dac.tar.gz
DiligentCore-43c3821993cb3d6ec3025fa7156da8544d2a1dac.zip
D3D12 resource binding refactoring, rename LinearAllocator to FixedLinearAllocator.
Diffstat (limited to 'Common/interface')
-rw-r--r--Common/interface/FixedLinearAllocator.hpp (renamed from Common/interface/LinearAllocator.hpp)16
1 files changed, 8 insertions, 8 deletions
diff --git a/Common/interface/LinearAllocator.hpp b/Common/interface/FixedLinearAllocator.hpp
index 78ee9166..d9302c5c 100644
--- a/Common/interface/LinearAllocator.hpp
+++ b/Common/interface/FixedLinearAllocator.hpp
@@ -28,7 +28,7 @@
#pragma once
/// \file
/// Defines Diligent::LinearAllocator class
#include <vector>
@@ -42,20 +42,20 @@ namespace Diligent
{
/// Implementation of a linear allocator on a fixed-size memory page
-class LinearAllocator
+class FixedLinearAllocator
{
public:
// clang-format off
- LinearAllocator (const LinearAllocator&) = delete;
- LinearAllocator& operator=(const LinearAllocator&) = delete;
- LinearAllocator& operator=(LinearAllocator&&) = delete;
+ FixedLinearAllocator (const FixedLinearAllocator&) = delete;
+ FixedLinearAllocator& operator=(const FixedLinearAllocator&) = delete;
+ FixedLinearAllocator& operator=(FixedLinearAllocator&&) = delete;
// clang-format on
- explicit LinearAllocator(IMemoryAllocator& Allocator) noexcept :
+ explicit FixedLinearAllocator(IMemoryAllocator& Allocator) noexcept :
m_pAllocator{&Allocator}
{}
- LinearAllocator(LinearAllocator&& Other) noexcept :
+ FixedLinearAllocator(FixedLinearAllocator&& Other) noexcept :
// clang-format off
m_pDataStart {Other.m_pDataStart },
m_pCurrPtr {Other.m_pCurrPtr },
@@ -67,7 +67,7 @@ public:
Other.Reset();
}
- ~LinearAllocator()
+ ~FixedLinearAllocator()
{
Free();
}
@@ -28,7 +28,7 @@
#pragma once
/// \file
-/// Defines Diligent::LinearAllocator class
+/// Defines Diligent::FixedLinearAllocator class
#include <vector>